==> brand-7.x-1.3.tar.gz: brand/src/Brand.php <==
<?php

/**
 * @file
 * Class file for the Brand class.
 */

/**
 * Brand is the class which contains the data for a given Brand.
 */
class Brand implements BrandInterface {

  /**
   * Raw contains the Raw value from the query before processing.
   *
   * @var object
   *   The raw value.
   */
  public static $Raw;
  /**
   * Brand contains the structured data for the Brand.
   *
   * @var object
   *   The data for the Brand.
   */
  public static $Brand;

  /**
   * Constructor.
   *
   * @inheritdoc
   */
  public function __construct(string $machine_name, int $timestamp = NULL, $skip_query = FALSE, $options = NULL) {

    // If the query has already run via Brands, we don't want to re-run it.
    if ($skip_query === TRUE) {
      if (NULL !== $options) {
        $obj = $options;
      }
      else {
        $obj = (object) array(
          'title' => '',
          'machine_name' => $machine_name,
          'description' => '',
          'date_created' => 0,
          'date_lock' => 0,
          'date_start' => 0,
          'date_finish' => 0,
          'path_visibility' => '',
          'content_type' => '',
          'theme' => '',
          'weight' => 0,
          'bid' => 0,
          'rid' => 0,
          'tid' => 0,
          'uid' => 0,
        );
      }
    }
    else {

      // We are tightly managing the schema through processing and
      // sensible defaults, and it's pretty stable.
      // Let's get all the fields so we can apply it.
      $data = db_select('brand', 'b');
      $data->fields('b');
      if (NULL !== $timestamp) {
        $data->condition('date_created', $timestamp, '=');
      }

      // Add the machine name as a condition and sort it.
      if ($machine_name !== '') {
        $data->condition('machine_name', $machine_name, '=');
      }

      $data->orderBy('b.date_created', 'ASC');

      // Execute and store it!
      $dataset = $data->execute()->fetchAll();

      self::$Raw = end($dataset);
      unset($dataset);

      // Return FALSE if nothing came back.
      if (empty(self::$Raw)) {
        self::$Brand = NULL;
        return;
      }

      // Otherwise turn it into a structured array.
      else {
        $obj = (object) array(
          'title' => self::$Raw->title,
          'machine_name' => self::$Raw->machine_name,
          'description' => self::$Raw->description,
          'date_created' => self::$Raw->date_created,
          'date_lock' => self::$Raw->date_lock,
          'date_start' => self::$Raw->date_start,
          'date_finish' => self::$Raw->date_finish,
          'path_visibility' => self::$Raw->path_visibility,
          'content_type' => self::$Raw->content_type,
          'theme' => self::$Raw->theme,
          'weight' => self::$Raw->weight,
          'bid' => self::$Raw->bid,
          'rid' => self::$Raw->rid,
          'tid' => self::$Raw->tid,
          'uid' => self::$Raw->uid,
        );
      }

    }
    self::$Brand = $obj;
  }

  /**
   * Check the brand to see if it's supposed to show.
   *
   * @inheritdoc
   */
  public function check() {
    if (user_has_role(self::$Brand->rid) || ((int) user_role_load(self::$Brand->rid)->rid === DRUPAL_ANONYMOUS_RID)) {
      if ((time() >= (int) self::$Brand->date_start && time() <= self::$Brand->date_finish) || (int) self::$Brand->date_lock === 1) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * Create a new database row based upon the current object.
   *
   * @inheritdoc
   */
  public function add(string $machine_name, array $options = array()) {
    if (user_access('brand creation')) {
      $query = db_insert('brand');
      $now = new DateTime();
      $title = (isset($options['title'])) ? $options['title'] : '';
      $description = (isset($options['description'])) ? $options['description'] : '';
      $date_created = $now->getTimestamp();
      $date_lock = (isset($options['date_lock'])) ? $options['date_lock'] : 0;
      $date_start = (isset($options['date_start'])) ? $options['date_start'] : $now->getTimestamp();
      $date_finish = (isset($options['date_finish'])) ? $options['date_finish'] : $now->getTimestamp();
      $path_visibility = (isset($options['path_visibility'])) ? $options['path_visibility'] : '';
      $content_type = (isset($options['content_type'])) ? $options['content_type'] : '';
      $theme = (isset($options['theme'])) ? $options['theme'] : '';
      $weight = (isset($options['weight'])) ? $options['weight'] : 0;
      $bid = (isset($options['bid'])) ? $options['bid'] : 0;
      $rid = (isset($options['rid'])) ? $options['rid'] : 0;
      $tid = (isset($options['tid'])) ? $options['tid'] : 0;
      $uid = (isset($options['uid'])) ? $options['uid'] : 0;
      $mapped_fields = array(
        'title' => $title,
        'machine_name' => $machine_name,
        'description' => $description,
        'date_created' => $date_created,
        'date_lock' => $date_lock,
        'date_start' => $date_start,
        'date_finish' => $date_finish,
        'path_visibility' => $path_visibility,
        'content_type' => $content_type,
        'theme' => $theme,
        'weight' => $weight,
        'bid' => $bid,
        'rid' => $rid,
        'tid' => $tid,
        'uid' => $uid,
      );
      $query->fields($mapped_fields);
      $query->execute();
      self::$Brand = (object) $mapped_fields;
    }
  }

  /**
   * Remove a database row based upon the current object.
   *
   * @inheritdoc
   */
  public function remove(int $timestamp = NULL) {
    if (user_access('brand removal')) {
      $machine_name = self::$Brand->machine_name;

      $q = db_delete('brand');
      $q->condition('machine_name', $machine_name, '=');
      if ($timestamp !== NULL) {
        $q->condition('date_created', $timestamp, '=');
        $q->execute();
        drupal_set_message(t("The record timestamped %time for brand %mname has been removed.", array('%time' => $timestamp, '%mname' => $machine_name)));
        drupal_goto("/admin/config/user-interface/brands/{$machine_name}");
      }
      else {
        $q->execute();
        drupal_set_message(t("The brand %mname has been removed.", array('%mname' => $machine_name)));
        drupal_goto("/admin/config/user-interface/brands/");
      }
    }
  }

  /**
   * Returns the $Brand object for code compliance checks.
   *
   * @return \stdClass
   *   The Brand object containing the data.
   */
  public function get() {
    return $this::$Brand;
  }

  /**
   * Returns the $Raw object for code compliance checks.
   *
   * @return \stdClass
   *   The Raw object containing the data.
   */
  public function raw() {
    return $this::$Raw;
  }

}

==> brand-7.x-1.4.tar.gz: brand/src/Brand.php <==
<?php

/**
 * @file
 * Class file for the Brand class.
 */

/**
 * Brand is the class which contains the data for a given Brand.
 */
class Brand implements BrandInterface {

  /**
   * Raw contains the Raw value from the query before processing.
   *
   * @var object
   *   The raw value.
   */
  protected $Raw;
  /**
   * Brand contains the structured data for the Brand.
   *
   * @var object
   *   The data for the Brand.
   */
  protected $Brand;

  /**
   * Constructor.
   *
   * @inheritdoc
   */
  public function __construct(string $machine_name, int $timestamp = NULL, $skip_query = FALSE, $options = NULL) {

    // If the query has already run via Brands, we don't want to re-run it.
    if ($skip_query === TRUE) {
      if (NULL !== $options) {
        $obj = $options;
      }
      else {
        $obj = (object) array(
          'title' => '',
          'machine_name' => $machine_name,
          'description' => '',
          'date_created' => 0,
          'date_lock' => 0,
          'date_start' => 0,
          'date_finish' => 0,
          'path_visibility' => '',
          'content_type' => '',
          'theme' => '',
          'weight' => 0,
          'bid' => 0,
          'rid' => 0,
          'tid' => 0,
          'uid' => 0,
        );
      }
    }
    else {

      // We are tightly managing the schema through processing and
      // sensible defaults, and it's pretty stable.
      // Let's get all the fields so we can apply it.
      $data = db_select('brand', 'b');
      $data->fields('b');
      if (NULL !== $timestamp) {
        $data->condition('date_created', $timestamp, '=');
      }

      // Add the machine name as a condition and sort it.
      if ($machine_name !== '') {
        $data->condition('machine_name', $machine_name, '=');
      }

      $data->orderBy('b.date_created', 'ASC');

      // Execute and store it!
      $dataset = $data->execute()->fetchAll();

      $this->Raw = end($dataset);
      unset($dataset);

      // Return FALSE if nothing came back.
      if (empty($this->Raw)) {
        $this->Brand = NULL;
        return;
      }

      // Otherwise turn it into a structured array.
      else {
        $obj = (object) array(
          'title' => $this->Raw->title,
          'machine_name' => $this->Raw->machine_name,
          'description' => $this->Raw->description,
          'date_created' => $this->Raw->date_created,
          'date_lock' => $this->Raw->date_lock,
          'date_start' => $this->Raw->date_start,
          'date_finish' => $this->Raw->date_finish,
          'path_visibility' => $this->Raw->path_visibility,
          'content_type' => $this->Raw->content_type,
          'theme' => $this->Raw->theme,
          'weight' => $this->Raw->weight,
          'bid' => $this->Raw->bid,
          'rid' => $this->Raw->rid,
          'tid' => $this->Raw->tid,
          'uid' => $this->Raw->uid,
        );
      }

    }
    $this->Brand = $obj;
  }

  /**
   * Check the brand to see if it's supposed to show.
   *
   * @inheritdoc
   */
  public function check() {
    if (user_has_role($this->Brand->rid) || ((int) user_role_load($this->Brand->rid)->rid === DRUPAL_ANONYMOUS_RID)) {
      if ((time() >= (int) $this->Brand->date_start && time() <= $this->Brand->date_finish) || (int) $this->Brand->date_lock === 1) {
        return TRUE;
      }
    }
    return FALSE;
  }

  /**
   * Create a new database row based upon the current object.
   *
   * @inheritdoc
   */
  public function add(string $machine_name, array $options = array()) {
    if (user_access('brand creation')) {
      $query = db_insert('brand');
      $now = new DateTime();
      $title = (isset($options['title'])) ? $options['title'] : '';
      $description = (isset($options['description'])) ? $options['description'] : '';
      $date_created = $now->getTimestamp();
      $date_lock = (isset($options['date_lock'])) ? $options['date_lock'] : 0;
      $date_start = (isset($options['date_start'])) ? $options['date_start'] : $now->getTimestamp();
      $date_finish = (isset($options['date_finish'])) ? $options['date_finish'] : $now->getTimestamp();
      $path_visibility = (isset($options['path_visibility'])) ? $options['path_visibility'] : '';
      $content_type = (isset($options['content_type'])) ? $options['content_type'] : '';
      $theme = (isset($options['theme'])) ? $options['theme'] : '';
      $weight = (isset($options['weight'])) ? $options['weight'] : 0;
      $bid = (isset($options['bid'])) ? $options['bid'] : 0;
      $rid = (isset($options['rid'])) ? $options['rid'] : 0;
      $tid = (isset($options['tid'])) ? $options['tid'] : 0;
      $uid = (isset($options['uid'])) ? $options['uid'] : 0;
      $mapped_fields = array(
        'title' => $title,
        'machine_name' => $machine_name,
        'description' => $description,
        'date_created' => $date_created,
        'date_lock' => $date_lock,
        'date_start' => $date_start,
        'date_finish' => $date_finish,
        'path_visibility' => $path_visibility,
        'content_type' => $content_type,
        'theme' => $theme,
        'weight' => $weight,
        'bid' => $bid,
        'rid' => $rid,
        'tid' => $tid,
        'uid' => $uid,
      );
      $query->fields($mapped_fields);
      $query->execute();
      $this->Brand = (object) $mapped_fields;
    }
  }

  /**
   * Remove a database row based upon the current object.
   *
   * @inheritdoc
   */
  public function remove(int $timestamp = NULL) {
    if (user_access('brand removal')) {
      $machine_name = $this->Brand->machine_name;

      $q = db_delete('brand');
      $q->condition('machine_name', $machine_name, '=');
      if ($timestamp !== NULL) {
        $q->condition('date_created', $timestamp, '=');
        $q->execute();
        drupal_set_message(t("The record timestamped %time for brand %mname has been removed.", array('%time' => $timestamp, '%mname' => $machine_name)));
        drupal_goto("/admin/config/user-interface/brands/{$machine_name}");
      }
      else {
        $q->execute();
        drupal_set_message(t("The brand %mname has been removed.", array('%mname' => $machine_name)));
        drupal_goto("/admin/config/user-interface/brands/");
      }
    }
  }

  /**
   * Returns the $Brand object for code compliance checks.
   *
   * @return \stdClass
   *   The Brand object containing the data.
   */
  public function get() {
    return $this->Brand;
  }

  /**
   * Returns the $Raw object for code compliance checks.
   *
   * @return \stdClass
   *   The Raw object containing the data.
   */
  public function raw() {
    return $this->Raw;
  }

}
